---
template: mainpage
source_form: markdown
name: Overview
title: Pyxie -- A Little Python to C++ Compiler
updated: October 2016
---
## Pyxie -- A Little Python to C++ Compiler

**Latest Release:** [0.1.25](changelog.html) (3/Feb/2018)

{% whatjobdoesthisdo = panel("panels/what-job-does-this-do.md") %}

### Show me something you CAN compile

Currently it can compile very very simple types of python program
that looks like this into an equivalent (simple) C++ program.

{% exampleprogram = panel("panels/example-program.md") %}

{% examplearduinoprogram = panel("panels/example-arduino-program.md") %}

{% examplearduinoservoprogram = panel("panels/example-arduino-servo-program.md") %}

{% examplearduinoanalogdemo = panel("panels/example-arduino-analog-demo.md") %}

{% whatdoesthisdo = panel("panels/what-does-this-do.md") %}

{% micropython_ref = panel("panels/why-not-micropython.md") %}

In the past I've written a test driven compiler suite, so I'll be following
the same approach here.  It did consider actually making Pyxie use that as a
frontend, but for the moment, I'd like python compatibility.

{% overview_status = panel("panels/overview-status.md") %}

{% influences = panel("panels/overview-influences.md") %}

{% python_version = panel("panels/which-version.md") %}

{% why_write_this = panel("panels/why-write-this.md") %}

{% faq_part_of_larger_project = panel("panels/faq-part-of-larger-project.md") %}

## Release History

Release History:

{% shortlog = panel("panels/shortlog.md") %}
